@@ -1,6 +1,7 @@
 import requests
 
-_ZACK_ROLE_DOCS = "https://cloud.docs.zalando.net/reference/zack-access-roles/"
+_NO_ROLES_FOUND_ERROR = """No roles found for cluster "{}", please request a role for the cluster's product community (see https://cloud.docs.zalando.net/howtos/product-clusters/ for details).
+If you already have the community role, please try requesting it again. It can fail to be provisioned correctly due to a bug in ZACK."""
 
 
 def check_cluster_permissions(cluster_url, cluster_alias, token):
@@ -19,8 +20,4 @@ def check_cluster_permissions(cluster_url, cluster_alias, token):
     response.raise_for_status()
     data = response.json()
     if not data["status"]["allowed"]:
-        raise ValueError(
-            'No role found for cluster "{}".\nPlease request a ZACK role, see "{}".'.format(
-                cluster_alias, _ZACK_ROLE_DOCS
-            )
-        )
+        raise ValueError(_NO_ROLES_FOUND_ERROR.format(cluster_alias))
