@@ -655,18 +655,22 @@ def tunnel(env: Environment, address, target, ports):
 
 
 def latest_socat_image():
-    docker_registry = "registry.opensource.zalan.do"
+    docker_registry = "container-registry.zalando.net"
     team = "teapot"
     artifact = "socat"
 
-    response = requests.get("https://{}/teams/{}/artifacts/{}/tags".format(docker_registry, team, artifact), timeout=10)
+    token = auth_token()
+
+    response = requests.get(
+        "https://{}/v2/{}/{}/tags/list".format(docker_registry, team, artifact),
+        timeout=10,
+        headers={"Authorization": "Bearer {}".format(token)},
+    )
     response.raise_for_status()
 
-    production_ready_images = [image for image in response.json() if image["status"] == "production_ready"]
-    if not production_ready_images:
-        raise Exception("No usable images found for {}/{}/{}".format(docker_registry, team, artifact))
+    image = response.json()
 
-    return "{}/{}/{}:{}".format(docker_registry, team, artifact, production_ready_images[-1]["name"])
+    return "{}/{}/{}:{}".format(docker_registry, team, artifact, image["tags"][-1])
 
 
 def generate_containers(target, ports, base_port, timeout):
